@@ -22,11 +22,7 @@
 #include <config.h>
 #endif
 #include <assert.h>
-#ifdef HAVE_NCURSESW
-#include <ncursesw/curses.h>
-#else
 #include <curses.h>
-#endif
 #include <signal.h>
 #include <fcntl.h>
 #include <unistd.h>
@@ -50,8 +46,9 @@
 #include <wchar.h>
 #endif /*HAVE_WCHAR_H*/
 
+#include <assuan.h>
+
 #include "pinentry.h"
-#include "assuan.h"
 
 /* FIXME: We should allow configuration of these button labels and in
    any case use the default_ok, default_cancel values if available.
@@ -250,7 +247,7 @@ dialog_create (pinentry_t pinentry, dialog_t dialog)
         if (!what)							\
 	  {								\
 	    err = 1;							\
-            pinentry->specific_err = ASSUAN_Locale_Problem;             \
+            pinentry->specific_err = gpg_error (GPG_ERR_LOCALE_PROBLEM); \
 	    goto out;							\
 	  }								\
       }									\
@@ -282,7 +279,7 @@ dialog_create (pinentry_t pinentry, dialog_t dialog)
 	  if (!new)							\
 	    {								\
 	      err = 1;							\
-              pinentry->specific_err = ASSUAN_Out_Of_Core;              \
+              pinentry->specific_err = gpg_error_from_syserror ();	\
 	      goto out;							\
 	    }								\
 									\
@@ -307,7 +304,7 @@ dialog_create (pinentry_t pinentry, dialog_t dialog)
       if (!dialog->which)						\
         {								\
 	  err = 1;							\
-          pinentry->specific_err = ASSUAN_Locale_Problem;               \
+          pinentry->specific_err = gpg_error (GPG_ERR_LOCALE_PROBLEM);	\
 	  goto out;							\
 	}								\
     }									\
@@ -373,7 +370,7 @@ dialog_create (pinentry_t pinentry, dialog_t dialog)
   if (y > size_y)
     {
       err = 1;
-      pinentry->specific_err = ASSUAN_Too_Short;
+      pinentry->specific_err = gpg_error (GPG_ERR_ASS_LINE_TOO_LONG);
       goto out;
     }
 
@@ -428,7 +425,7 @@ dialog_create (pinentry_t pinentry, dialog_t dialog)
   if (x > size_x)
     {
       err = 1;
-      pinentry->specific_err = ASSUAN_Too_Short;
+      pinentry->specific_err = gpg_error (GPG_ERR_ASS_LINE_TOO_LONG);
       goto out;
     }
 
@@ -704,7 +701,11 @@ dialog_input (dialog_t diag, int alt, int chr)
   switch (chr)
     {
     case KEY_BACKSPACE:
-    case 'h' - 'a' + 1: /* control-h.  */
+      /* control-h.  */
+    case 'h' - 'a' + 1:
+      /* ASCII DEL.  What Mac OS X apparently emits when the "delete"
+	 (backspace) key is pressed.  */
+    case 127:
       if (diag->pin_len > 0)
 	{
 	  diag->pin_len--;
@@ -833,7 +834,7 @@ dialog_run (pinentry_t pinentry, const char *tty_name, const char *tty_type)
       ttyfi = fopen (tty_name, "r");
       if (!ttyfi)
         {
-          pinentry->specific_err = ASSUAN_ENOENT;
+          pinentry->specific_err = gpg_error_from_syserror ();
           return -1;
         }
       ttyfo = fopen (tty_name, "w");
@@ -842,7 +843,7 @@ dialog_run (pinentry_t pinentry, const char *tty_name, const char *tty_type)
 	  int err = errno;
 	  fclose (ttyfi);
 	  errno = err;
-          pinentry->specific_err = ASSUAN_ENOENT;
+          pinentry->specific_err = gpg_error_from_syserror ();
 	  return -1;
 	}
       screen = newterm (tty_type, ttyfo, ttyfi);
@@ -855,7 +856,7 @@ dialog_run (pinentry_t pinentry, const char *tty_name, const char *tty_type)
           if (!(isatty(fileno(stdin)) && isatty(fileno(stdout))))
             {
               errno = ENOTTY;
-              pinentry->specific_err = ASSUAN_ENOTTY;
+              pinentry->specific_err = gpg_error_from_syserror ();
               return -1;
             }
 	  init_screen = 1;
