@@ -193,6 +193,11 @@ struct pinentry
      to save the assuan ctx.  */
   void *ctx_assuan;
 
+  /* An UTF-8 string with an invisible character used to override the
+     default in some pinentries.  Only the first character is
+     used.  */
+  char *invisible_char;
+
 };
 typedef struct pinentry *pinentry_t;
 
@@ -211,7 +216,10 @@ typedef int (*pinentry_cmd_handler_t) (pinentry_t pin);
    error.  Otherwise, 0 is returned.  */
 int pinentry_loop (void);
 
-/* The same as above but allows to specify the i/o descriptors. */
+/* The same as above but allows to specify the i/o descriptors.
+ * infd and outfd will be duplicated in this function so the caller
+ * still has to close them if necessary.
+ */
 int pinentry_loop2 (int infd, int outfd);
 
 
